==> haskell-aeson-pretty-0.8.9-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-pretty
version:              0.8.9
visibility:           public
id:                   aeson-pretty-0.8.9-BnsQSvnbim1C4mQi8V8YJl
key:                  aeson-pretty-0.8.9-BnsQSvnbim1C4mQi8V8YJl
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  2b87210223ce6698b7dc6772b570834a
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-pretty-0.8.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-pretty-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-pretty
hs-libraries:         HSaeson-pretty-0.8.9-BnsQSvnbim1C4mQi8V8YJl
depends:
    aeson-1.5.6.0-9Pr07X4KYAQGYkzJzuJMP6 base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    scientific-0.3.7.0-48Wj4PpHzxKAvlz1kMpDrM text-1.2.5.0
    unordered-containers-0.2.19.1-BhRjg5By7kU7pLGfSxEo3F
    vector-0.12.3.1-J4wWiZyTUBGFVf3h0yMQvX

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.9-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-pretty
version:              0.8.9
visibility:           public
id:                   aeson-pretty-0.8.9-4FM0CqUjksBBvSARdoqSRK
key:                  aeson-pretty-0.8.9-4FM0CqUjksBBvSARdoqSRK
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  f70a419bcb217b15f622aa5748ba7d23
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.0.2/site-local/aeson-pretty-0.8.9
library-dirs:         /usr/lib/ghc-9.0.2/site-local/aeson-pretty-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-pretty
hs-libraries:         HSaeson-pretty-0.8.9-4FM0CqUjksBBvSARdoqSRK
depends:
    aeson-1.5.6.0-D6JFXMoVVY440Mpm8YlAiW base-4.15.1.0
    base-compat-0.12.1-Jgs1a6JPC25AMVxb7dCwve bytestring-0.10.12.1
    scientific-0.3.7.0-2bBilO5AY4p7o0WHMnmlyC text-1.2.5.0
    unordered-containers-0.2.19.1-7SQ4DJN6rki64sevxnHKhZ
    vector-0.12.3.1-Im4rxp8YGWIHuHWC3z5rRi

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
